@@ -1,6 +1,6 @@
 package Geo::DNA;
 
-our $VERSION = "0.3";
+our $VERSION = "0.31";
 
 use common::sense;
 
@@ -26,6 +26,11 @@ my $DECODE_MAP = {
     'c' => 3,
 };
 
+sub _mod {
+    my ( $x, $m ) = @_;
+    return fmod( fmod( $x, $m ) + $m, $m);
+}
+
 sub encode_geo_dna {
     my ( @args ) = @_;
     encode( @args );
@@ -91,7 +96,7 @@ sub decode {
     my ( $lati, $loni ) = bounding_box( $geodna );
 
     my $lat = ( $lati->[0] + $lati->[1] ) / 2;
-    my $lon = ( $loni->[0] + $loni->[0] ) / 2;
+    my $lon = ( $loni->[0] + $loni->[1] ) / 2;
     if ( $options->{radians} ) {
         return ( deg2rad( $lat ), deg2rad( $lon ) );
     }
@@ -138,8 +143,8 @@ sub add_vector {
     my ( $lat, $lon, $dy, $dx ) = @_;
 
     return (
-        fmod( ( $lat + 90.0 + $dy ), 180.0 ) - 90.0,
-        fmod( ( $lon + 180.0 + $dx ), 360.0 )  - 180.0
+        _mod( ( $lat + 90.0 + $dy ), 180.0 ) - 90.0,
+        _mod( ( $lon + 180.0 + $dx ), 360.0 )  - 180.0
     );
 }
 
@@ -189,7 +194,7 @@ Geo::DNA - Encode latitude and longitude in a useful string format
 
 =head1 VERSION
 
-    0.03
+    0.31
 
 
 =head1 FEATURES
@@ -211,6 +216,9 @@ It's just basic space partitioning, really.
 
 =head1 DESCRIPTION
 
+NEW: see an interactive demo of Geo::DNA codes at
+http://www.shoffle.com/geodna-js/docs/google-maps.html
+
 This is a Perl version of the Python "geoprint" system that we developed
 a few years back at Action Without Borders.
 
@@ -326,7 +334,7 @@ Please report bugs relevant to C<GeoDNA> to E<lt>info[at]kyledawkins.comE<gt>.
 
 =head1 CONTRIBUTING
 
-The github repository is at https://quile@github.com/quile/geodna-perl.git
+The github repository is at git://github.com/quile/geodna-perl.git.
 
 
 =head1 SEE ALSO
